@@ -70,7 +70,7 @@
 
   ## deal with X
   ## null model support
-  X <- if (!is.empty.model(mt)) model.matrix(mt, mf, contrasts)
+  X <- if (!is.empty.model(mt)) model.matrix(mt, mf)
   X <- as.matrix(X)         # X matrix
   xvars <- dimnames(X)[[2]] # X variable names
   xobs  <- dimnames(X)[[1]] # X observation names
@@ -366,10 +366,10 @@
 #'
 #' Andrew D. Martin, Kevin M. Quinn, and Jong Hee Park. 2011.  ``MCMCpack:
 #' Markov Chain Monte Carlo in R.'', \emph{Journal of Statistical Software}.
-#' 42(9): 1-21.  \url{http://www.jstatsoft.org/v42/i09/}.
+#' 42(9): 1-21.  \url{https://www.jstatsoft.org/v42/i09/}.
 #'
 #' Daniel Pemstein, Kevin M. Quinn, and Andrew D. Martin.  2007.  \emph{Scythe
-#' Statistical Library 1.0.} \url{http://scythe.wustl.edu}.
+#' Statistical Library 1.0.} \url{http://scythe.lsa.umich.edu}.
 #'
 #' Radford Neal. 2003. ``Slice Sampling'' (with discussion). \emph{Annals of
 #' Statistics}, 31: 705-767.
